mix'EM 
======

mixem is a pure-python implementation of the Expectation-Maximization (EM) algorithm for fitting mixtures of distributions. It works in Python 2 and Python 3 (tested with 2.7 and 3.5.1).

Features
--------

 * Built-in support for several distributions
 * Easily define custom distributions

Dependencies
------------

 * NumPy v1.7.0 or newer
 * SciPy v0.14.0 or newer

Installation
------------

    pip install mixem
